==> chemistry-opencmis-client-bindings-0.6.0-sources.jar: org/apache/chemistry/opencmis/client/bindings/spi/atompub/objects/AtomAllowableActions.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.chemistry.opencmis.client.bindings.spi.atompub.objects;

import org.apache.chemistry.opencmis.commons.impl.jaxb.CmisAllowableActionsType;

/**
 * AtomAllowableActions.
 */
public class AtomAllowableActions extends AtomBase {

    private static final long serialVersionUID = 1L;

    private CmisAllowableActionsType allowableActions;

    public AtomAllowableActions() {
        super();
    }

    public AtomAllowableActions(CmisAllowableActionsType allowableActions) {
        this();
        setAllowableActions(allowableActions);
    }

    @Override
    public String getType() {
        return "Allowable Actions";
    }

    public CmisAllowableActionsType getAllowableActions() {
        return allowableActions;
    }

    public void setAllowableActions(CmisAllowableActionsType allowableActions) {
        this.allowableActions = allowableActions;
    }
}

==> chemistry-opencmis-client-bindings-1.0.0-sources.jar: org/apache/chemistry/opencmis/client/bindings/spi/atompub/objects/AtomAllowableActions.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.chemistry.opencmis.client.bindings.spi.atompub.objects;

import org.apache.chemistry.opencmis.commons.data.AllowableActions;

/**
 * AtomAllowableActions.
 */
public class AtomAllowableActions extends AtomBase {

    private static final long serialVersionUID = 1L;

    private AllowableActions allowableActions;

    public AtomAllowableActions() {
        super();
    }

    public AtomAllowableActions(AllowableActions allowableActions) {
        this();
        this.allowableActions = allowableActions;
    }

    @Override
    public String getType() {
        return "Allowable Actions";
    }

    public AllowableActions getAllowableActions() {
        return allowableActions;
    }

    public void setAllowableActions(AllowableActions allowableActions) {
        this.allowableActions = allowableActions;
    }
}
